@@ -63,16 +63,11 @@ class Excel:
             to_excel_kwargs.pop('engine')
 
         writer = pd.ExcelWriter(filename, engine='openpyxl', mode='a', if_sheet_exists='overlay')
-
-        # try to open an existing workbook
-        # writer.book = load_workbook(filename)
-
-        if sheet_name in writer.book.sheetnames:
-            header = False
         
-        # get the last row in the existing Excel sheet
-        # if it was not specified explicitly
-        if startrow is None and sheet_name in writer.book.sheetnames:
+        # get the last row in the existing Excel sheet if it was not specified explicitly
+        if startrow is None:
+            startrow = 0
+        elif startrow is None and sheet_name in writer.book.sheetnames:
             startrow = writer.book[sheet_name].max_row
 
         # truncate sheet
@@ -93,9 +88,6 @@ class Excel:
         # copy existing sheets
         # writer.sheets = { ws.title:ws for ws in writer.book.worksheets }
 
-        if startrow is None:
-            startrow = 0
-
         # make columns filterable
         writer.book.active.auto_filter.ref = writer.book.active.dimensions
 
@@ -119,6 +111,7 @@ class Excel:
             # write dataframe to excel
             data = pd.DataFrame(data)
             data.to_excel(writer, sheet_name=sheet_name, index=False)
+        
         # save the excel
         writer.save()
 
@@ -139,7 +132,10 @@ class Excel:
                 sheet = writer.book.worksheets[i]
                 break
         if sheet is None:
-            sheet = writer.book.create_sheet(sheet_name, writer.book.sheetnames)
+            sheet = writer.book.create_sheet(sheet_name, len(writer.book.sheetnames))
         
         picture = openpyxl.drawing.image.Image(imagename)
-        sheet.add_image(picture, cell)
\ No newline at end of file
+        sheet.add_image(picture, cell)
+
+        # save the excel
+        writer.save()
\ No newline at end of file
